use strict;
use warnings;
use Test::More tests => 2;

use YAML ();
use YAML::Any ();
use YAML::API ();

cmp_ok(YAML->VERSION, 'eq', YAML::Any->VERSION, "YAML::Any version equals YAML version");
cmp_ok(YAML->VERSION, 'eq', YAML::API->VERSION, "YAML::API version equals YAML version");
